/*-----------------------------------------------
	Draw a surface from X/Y data
	launch another window with another ideal distance
------------------------------
  COMMON VARIABLES:
     int Mgraph_no Sequence number of the software;
                      several Mgraph can be launched at the same time id (several Mgraph can be launched)
     int nwindow   Number of window in which the data will be shown (-1=Current)
     int color     Number of the color: from 0 to 12:
                          Red, Blue, Magenta, Black, Green, Forest, Sienna,
                          Yellow, Coral, Violet, Plum, Cyan, Turquoise
                          Plum, Cyan,Turquoise
                      and 16 for the White
     int linestyle Style of the line: from 0 to 7:
                          Solid, NoLine, MicroDash, SmallDash,
                         Dash, LongDash, DashDot, LineDot
     int marker    Style of the marker: from 0 to 15:
                          NoMark, BigDot, SmallDot, Cross, X, Square,
                          Diamond, TriangleUp, TriangleDown, Circle
                          filled: Square, Diamond, TriangleUp, TriangleDown, Circle
-----------------------------------------------*/


#include <stdio.h>
#include <math.h>

#define FALSE 0
#define TRUE  1

#define LOGIN NULL
#define SHELL NULL
#define PATH "/usr/local/bin"
#define PROG "Mgraph_sp"
#define COMPUTER NULL
#define DISPLAY NULL
#define X_FORMULA NULL
#define Y_FORMULA NULL

int color[] =    { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
int color2[] =    { 3, 4, 5, 3, 4, 5, 6, 7, 8, 9 };
int linetype[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
int marktype[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
int dolabel[] =  { 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 };
int addings[] =  { 1, 0, 0, 0 };
float pix[]   =  { 0.0,0.0,0.0,0.0 };
short   red[256],green[256],blue[256];
char *FORMAT = "%3.0f";
float cont[] = {20.0,40.0,60.0,100.0};

main()
{
float xmin = -1.,    xmax = 25.,  ymin = -1.,   ymax = 1.;
float xstep = .30 ,  ystep = -1., xbase = -1.,  ybase = -1.;
float Ideal;

int   mgraph_no = 1, nbp = 512,   nwindow=1;
int   xlog = 0,      ylog = 0,    xtic = -1,    ytic = -1.;
int   draw = 1,      clear = 0;
int   zunits = 1 ,   AddMode = FALSE, nlut = 4;
int   near=FALSE;
	
float *xx,*yy;
int i,j,n,plot_no,nb_cont;


	xx = (float *) malloc( sizeof(float) * nbp * 10 );
	yy = (float *) malloc( sizeof(float) * nbp * 10 );

/*=================================================================================================
 START MGRAPH_SP MODULE WITH NO DISPLAY: run_mgraph_no_display
        LOGIN:  login name;             if NULL will be the current login
        SHELL:  "rsh" or "remsh";       if NULL will be  "remsh"
        PATH :  path where the program is
        PROG :  name of the program (Mgraph_sp)
        COMPUTER:       name of the computer where the program has to
                        be launched;    if NULL will be the server name
        DISPLAY: Your Display Id;       if NULL will be your DISPLAY address
                                             from your environment
=================================================================================================*/

	if(!run_mgraph(mgraph_no,LOGIN,SHELL,PATH,PROG,COMPUTER,DISPLAY))
	{
		printf("Cannot start Mgraph\n");
		exit(0);
	}

/*=================================================================================================
	SEND_RESIZE
	nwindow    = Window number(1->10) in which data will be shown (-1=Current)
	width      = window width in pixel
	height     = window height in pixel
=================================================================================================*/

	send_resize(mgraph_no,nwindow,600,500);

/*-----------------------------------------------
send_title(client_id,window,title);
char    *title;  the window title
-----------------------------------------------*/

	send_title(mgraph_no,nwindow,"Compute a surface from a x/y plot");

/*------------------------------------------------
SEND AXES
send_xaxes2(client_id,window,legend,format,label_size,min,max,grid,
            color,thickness,rotation,step,ref,tick,log,Formula);

        CAREFUL with types !!!
      char  legend               The text which is displayed under the axis
      char  format               the C format formulation   ("%.2f" for ex.)
      float label size           factor on label size
      float min,max              the limits of axis (-1 : uses the best)
      int   grid                 10= grid 11= half tone 12= no grid
      int   color                color type (3=black)
      int   thickness            thickness of the line factor
      float rotation             label text rotation in degrees
      float step                 the step in your units between two ticks (-1:uses the best)
      float ref                  reference value   (-1 : uses the best)
      int   tick                 step (in ticks) between two labeled ticks  (-1 : uses the best)
      int   log                  0=linear 1=logarithm  2=formula 3=time  4=degree
      char  Formula[]            (if log = 2)
------------------------------------------------*/

 	send_xaxes2(mgraph_no,nwindow,"Angle","%.1f",1.0,
			xmin,xmax,12,3,1,0.0,xstep,xbase,xtic,xlog,X_FORMULA);
	send_yaxes2(mgraph_no,nwindow,"sin(x)","%.1f",1.0,
			ymin,ymax,12,3,1,0.0,ystep,ybase,ytic,ylog,Y_FORMULA);

	n=0;
	for(j=1;j<10;j++){
	    for(i=0;i<nbp;i++){
	        xx[n] = i * 3.141592 * j / nbp;
	        yy[n] = sin((double)xx[n]) / j;
		/*printf(" %f %f \n",xx[n],yy[n]);*/
		n++;
	    }
	    }
	nbp = n;

/*=================================================================================================
SEND X/Y arrays TO BUILD A SURFACE ON CURRENT WINDOW

   allow you to create a surface from x, y values                             
   int mgraph_no	Client id                                              
   int nwindow  (0->9)  Window number in which data will be shown (-1=Current) 
   int nbp              Number of points in the data                            
   float x[nbp] 	x values                                                              
   float y[nbp] 	y values                                                            
   int nb_cont          number of contour values                            
   float cont[nb_cont]  contour values 
   int color[nb_cont]            (0->12)                                           
                        Red, Blue, Magenta, Black, Green, Forest, Sienna, Yellow,
                        Coral, Violet, Plum, Cyan, Turquoise            
   int style[nb_cont]            (0->7)      Line style                          
                        Solid, NoLine, MicroDash, SmallDash, Dash, LongDash,
                        DashDot, LineDot                              
   int mark[nb_cont]              (0->15)     Mark type                        
                        NoMark, BigDot, SmallDot, Cross, X, Square, Diamond,
                        TriangleUp, TriangleDown, Circle
                        filled: Square, Diamond, TriangleUp, TriangleDown, Circle
   int dolabel[nb_cont] Draw label                                           
   int addings[4]       addings              
   float Ideal          Ideal distance label factor                       
   float pix            Color tranformation minv maxv minp maxp           
   int nlut             if 0 no lut 
   short Red[256]
   short Green[256]
   short Blue[256]
   int near 		pixel interpolation                                          
   char Format[]        label format                                
   int AddMode          TRUE add mode on graphic window     
   float xmin           Box x minimum                                     
   float xmax           Box x maximun                                    
   float xstep          Box x size                                      
   float ymin           Box y minimum                                  
   float ymax           Box y maximun                                 
   float ystep          Box y size                                   
   int zunits           0 = box (pixel nb), 1 =  % of pixels within a box  
=================================================================================================*/

	xmin=0; xmax = 30; xstep = 1.5;
	ymin=-0.5; ymax = 1; ystep = 0.075;
	xmin = xmax = 0;
	ymin = ymax = 0;

	/*nlut = 256;  TEST user lut
	for(i=0;i<256;i++){
	red[i] = i;
	green[i] = i;
	blue[i] = i;
	}*/

	nb_cont = 4;
	Ideal = 4.0;
	send_buildsurface(mgraph_no,nwindow,nbp,xx,yy,nb_cont,cont,color,linetype,marktype,dolabel,
	addings,Ideal,pix,nlut,red,green,blue,near,FORMAT,
	xmin,xmax,xstep,ymin,ymax,ystep,zunits);

	send_resize(mgraph_no,2,600,300);
	nb_cont = 0;
	Ideal = 1.0;
	nlut = 2;
	send_title(mgraph_no,2,"the same surface with ideal distance of 1.");
 	send_xaxes2(mgraph_no,2,"Angle","%.2f",-1.,
			-1.,-1.,10,3,1,0.0,-1.,-1.,-1.,xlog,X_FORMULA);
	send_yaxes2(mgraph_no,2,"sin(x)","%.2f",-1.,
			-1.,-1.,10,3,1,0.0,-1.,-1.,-1.,ylog,Y_FORMULA);

	send_buildsurface(mgraph_no,2,nbp,xx,yy,nb_cont,cont,color,linetype,marktype,dolabel,
	addings,Ideal,pix,nlut,red,green,blue,near,FORMAT,
	xmin,xmax,xstep,ymin,ymax,ystep,zunits);

/*------------------------------------------------
EXIT_MAIN_PROGRAM
        before quitting your main program,  call send_end_dialog
        to keep Mgraph running
------------------------------------------------*/


	send_end_dialog(mgraph_no);

	free(xx);
	free(yy);
}
