c-----------------------------------------------
c       Draw a surface from X/Y data
c       launch another window with another ideal distance
c-----------------------------
c COMMON VARIABLES:
c    int Mgraph_no Sequence number of the software;
c                     several Mgraph can be launched at the same time id (several Mgraph can be launched)
c    int nwindow   Number of window in which the data will be shown (-1=Current)
c    int color     Number of the color: from 0 to 12:
c                         Red, Blue, Magenta, Black, Green, Forest, Sienna,
c                         Yellow, Coral, Violet, Plum, Cyan, Turquoise
c                         Plum, Cyan,Turquoise
c                     and 16 for the White
c    int linestyle Style of the line: from 0 to 7:
c                         Solid, NoLine, MicroDash, SmallDash,
c                        Dash, LongDash, DashDot, LineDot
c    int marker    Style of the marker: from 0 to 15:
c                         NoMark, BigDot, SmallDot, Cross, X, Square,
c                         Diamond, TriangleUp, TriangleDown, Circle
c                         filled: Square, Diamond, TriangleUp, TriangleDown, Circle
c----------------------------------------------*/

      CHARACTER*(*) PROG,PATH,COMPUTER,DISPLAY,LOGIN,SHELL
      PARAMETER (LOGIN=" ")
      PARAMETER (SHELL='rsh')
      PARAMETER (PATH ='/usr/local/bin/')
      PARAMETER (PROG ='Mgraph_sp')
      PARAMETER (COMPUTER = " ")
      PARAMETER (DISPLAY ='0:0')

      real cont(10),pix(4),xx(6000),yy(6000)
      integer color(10),linetype(10),marktype(10),dolabel(10),addings(4)
      integer *2 red(256),green(256),blue(256)

      integer mgraph_no,i,j
      integer nbp,nwindow,xlog,ylog,xtic,ytic
      integer zunits,nlut,near	
      real xmin,xmax,ymin,ymax,xstep,ystep,xbase,ybase,Ideal

      data cont /20.0,40.0,60.0,100.0,6*0.0/	
      data color    / 0,1,2,3,4,5,6,7,8,9 /
      data linetype / 0,0,0,0,0,0,0,0,0,0 /
      data marktype / 0,0,0,0,0,0,0,0,0,0 /
      data dolabel  / 1,1,1,1,1,1,1,1,1,1 /
      data addings  / 1,0,0,0 /
      data pix      / 0.0,0.0,0.0,0.0 /
      data mgraph_no /1/
      data nbp,id,xlog,ylog,xtic,ytic/512,1,0,0,-1,-1/
      data zunits,nlut,near/1,4,0/
      data xmin,xmax,ymin,ymax,xstep,ystep,xbase,ybase,Ideal
     *   /-1,25,-1,1.,.3,-1,-1,-1,4.0/


C/*=================================================================================================
c START MGRAPH_SP MODULE WITH NO DISPLAY: run_mgraph_no_display
c        LOGIN:  login name;             if NULL will be the current login
c        SHELL:  "rsh" or "remsh";       if NULL will be  "remsh"
c        PATH :  path where the program is
c        PROG :  name of the program (Mgraph_sp)
c        COMPUTER:       name of the computer where the program has to
c                        be launched;    if NULL will be the server name
c        DISPLAY: Your Display Id;       if NULL will be your DISPLAY address
c                                             from your environment
C=================================================================================================*/

	call run_mgraph_f
     *	(mgraph_no,LOGIN,SHELL,PATH,PROG,COMPUTER,DISPLAY)

C/*=================================================================================================
C	SEND_RESIZE
C	nwindow    = Window number(1->10) in which data will be shown (-1=Current)
C	width      = window width in pixel
C	height     = window height in pixel
C=================================================================================================*/

	call send_resize_f(mgraph_no,nwindow,600,500)

C/*=================================================================================================
c send_title(client_id,window,title);
c character     title[]  the window title
C=================================================================================================*/

C
	call send_title_f
     * (mgraph_no,nwindow,"Compute a surface from a x/y plot")

c=====================================================================
c SEND AXES
c         CAREFUL with types !!!
c    call send_xaxes2_f(client_id,window,legend,format,label_size,min,max,grid,
c            color,thickness,rotation,step,ref,tick,log,Formula)
c       character*  legend             The text which is displayed under the axis
c       character*  format             the C format formulation   ("%.2f" for ex.)
c       real        label size         factor on label size
c       real        min,max            the limits of axis (-1 : uses the best)
c       integer     grid               10= grid 11= half tone 12= no grid
c       integer     color              color type (3=black)
c       integer     thickness          thickness of the line factor
c       real        rotation           label text rotation in degrees
c       real        step               the step in your units between two ticks (-1:uses the best)
c       real        ref                reference value   (-1 : uses the best)
c       integer     tick               step (in ticks) between two labeled ticks  (-1 : uses the best)
c       integer     log                0=linear 1=logarithm  2=formula 3=time  4=degree
c       character*  Formula            (if log = 2)
c=====================================================================

 	call send_xaxes2_f(mgraph_no,nwindow,"Angle","%.1f",1.0,
     *  xmin,xmax,12,3,1,0.0,xstep,xbase,xtic,xlog," ")
	call send_yaxes2_f(mgraph_no,nwindow,"sin(x)","%.1f",1.0,
     * ymin,ymax,12,3,1,0.0,ystep,ybase,ytic,ylog," ")

	n=0
	do j=1,10
	    do i=0,nbp
	        xx(n) = i * 3.141592 * j / nbp
	        yy(n) = sin(xx(n)) / j
		n=n+1
	    enddo
	    enddo
	nbp = n

C/*=================================================================================================
C   SEND X/Y ARRAYS to compute a surface 
c	call send_buildsurface_f (mgraph_no,nwindow,nbp,xx,yy,nb_cont,
c    *  cont,color,linetype,marktype,dolabel,
c    *  addings,Ideal,pix,nlut,red,green,blue,near,FORMAT,
c    *  xmin,xmax,xstep,ymin,ymax,ystep,zunits)
C
c  integer nbp              	Number of points in the data
c  real x[nbp]         		x values
c  real y[nbp]         		y values
c  integer nb_cont          	number of contour values
c  real cont[nb_cont]  		contour values
c  integer color[nb_cont]            (0->12)
c                       Red, Blue, Magenta, Black, Green, Forest, Sienna, Yellow,
c                       Coral, Violet, Plum, Cyan, Turquoise
c  integer style[nb_cont]            (0->7)      Line style
c                       Solid, NoLine, MicroDash, SmallDash, Dash, LongDash,
c                       DashDot, LineDot
c  integer mark[nb_cont]              (0->15)     Mark type
c                       NoMark, BigDot, SmallDot, Cross, X, Square, Diamond,
c                       TriangleUp, TriangleDown, Circle
c                       filled: Square, Diamond, TriangleUp, TriangleDown, Circle
c  integer dolabel[nb_cont] 	Draw label
c  integer addings[4]       	addings
c  real Ideal          		Ideal distance label factor
c  real pix            		Color tranformation minv maxv minp maxp
c  integer nlut             	if 0 no lut
c  integer*2 Red[256]
c  integer*2 Green[256]
c  integer*2 Blue[256]
c  integer near             	pixel interpolation
c  character*10 Format        	label format
c  integer AddMode          	TRUE add mode on graphic window
c  real xmin           	Box x minimum
c  real xmax           	Box x maximun
c  real xstep          	Box x size
c  real ymin           	Box y minimum
c  real ymax           	Box y maximun
c  real ystep          	Box y size
c  integer zunits           	0 = box (pixel nb), 1 =  % of pixels within a box
C=================================================================================================*/
C
	xmin=0
        xmax = 30
        xstep = 1.5
	ymin=-0.5
        ymax = 1
        ystep = 0.075
	xmin = 0
        xmax = 0
	ymin = 0
        ymax = 0

	nb_cont = 4
	Ideal = 4.0
	call send_buildsurface_f(mgraph_no,nwindow,nbp,xx,yy,nb_cont,
     *  cont,color,linetype,marktype,dolabel,
     *	addings,Ideal,pix,nlut,red,green,blue,near,FORMAT,
     *  xmin,xmax,xstep,ymin,ymax,ystep,zunits)

	call send_resize_f(mgraph_no,2,600,300)
	call send_title_f
     * (mgraph_no,2,"the same surface with ideal distance of 1.")
 	call send_xaxes2_f(mgraph_no,2,"Angle","%.2f",1.0,
     *  -1.,-1.,12,3,1,0.0,-1.,-1.,-1.,xlog," ")
	call send_yaxes2_f(mgraph_no,2,"sin(x)","%.2f",1.0,
     * -1.,-1.,12,3,1,0.0,-1.,-1.,-1.,ylog," ")

	nb_cont = 0
	Ideal = 1.0
	nlut = 2
	call send_buildsurface_f(mgraph_no,2,nbp,xx,yy,nb_cont
     *  ,cont,color,linetype,marktype,dolabel,
     *	addings,Ideal,pix,nlut,red,green,blue,near,FORMAT,
     *	xmin,xmax,xstep,ymin,ymax,ystep,zunits)

C/*=================================================================================================
C	EXIT_MAIN_PROGRAM */
C
	call send_end_dialog_f(mgraph_no)
	stop
        end

